@@ -35,11 +35,11 @@ class Command(BaseCommand):
                 from tendenci.apps.pages.tasks import PagesExportTask
                 result = PagesExportTask()
                 response = result.run()
-            elif export.app_label == 'memberships' and export.model_name == 'membership':
-                from tendenci.addons.memberships.tasks import MembershipsExportTask
-                kwargs = {'app': export.memb_app}
-                result = MembershipsExportTask()
-                response = result.run(**kwargs)
+#             elif export.app_label == 'memberships' and export.model_name == 'membership':
+#                 from tendenci.addons.memberships.tasks import MembershipsExportTask
+#                 kwargs = {'app': export.memb_app}
+#                 result = MembershipsExportTask()
+#                 response = result.run(**kwargs)
             elif export.app_label == 'profiles' and export.model_name == 'profile':
                 from tendenci.apps.profiles.tasks import ExportProfilesTask
                 result = ExportProfilesTask()
